# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# With UsrMove (F-17, RHEL-7 onwards), we want the library installed to %%{_libdir} rather than /%%{_lib}
%global UsrMove %([ 0%{?fedora} -gt 16 -o 0%{?rhel} -gt 6 ] && echo 1 || echo 0)

# Determine location of fipshmac binary
%global __fipshmac %([ -x /usr/bin/fipshmac ] && echo /usr/bin/fipshmac || echo /bin/fipshmac)

Name:		libgcrypt
Version:	1.5.6
Release:	1.0.cf.%{__distinit}%{__distvers}
# Technically LGPLv2.1+, but Fedora's table doesn't draw a distinction.
# Documentation and some utilities are GPLv2+ licensed.
# These files are in the devel subpackage.
License:	LGPLv2+
Summary:	A general-purpose cryptography library
Group:		System Environment/Libraries
URL:		http://www.gnupg.org/
Source0:	ftp://ftp.gnupg.org/gcrypt/libgcrypt/libgcrypt-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/libgcrypt/libgcrypt-%{version}.tar.bz2.sig
Source2:	wk@g10code.com
# make FIPS hmac compatible with fipscheck - non upstreamable
Patch2:		libgcrypt-1.5.0-use-fipscheck.patch
# fix tests in the FIPS mode, fix the FIPS-186-3 DSA keygen
Patch5:		libgcrypt-1.5.0-tests.patch
# make the FIPS-186-3 DSA CAVS testable
Patch7:		libgcrypt-1.5.3-fips-cavs.patch
# fix for memory leaks and other errors found by Coverity scan
Patch9:		libgcrypt-1.5.0-leak.patch
# use poll instead of select when gathering randomness
Patch11:	libgcrypt-1.5.1-use-poll.patch
# Compile rijndael with -fno-strict-aliasing
Patch12:	libgcrypt-1.5.2-aliasing.patch
# slight optimalization of mpicoder.c to silence Valgrind (#968288)
Patch13:	libgcrypt-1.5.2-mpicoder-gccopt.patch
# pbkdf2 speedup - upstream
Patch15:	libgcrypt-1.5.3-pbkdf-speedup.patch
# Fix bug in whirlpool implementation (for backwards compatibility
# with files generated with buggy version set environment
# variable GCRYPT_WHIRLPOOL_BUG)
Patch16:	libgcrypt-1.5.3-whirlpool-bug.patch
# FIPS DRBG
Patch17:	libgcrypt-1.5.6-drbg.patch
# Run the FIPS mode initialization in the shared library constructor
Patch18:	libgcrypt-1.5.3-fips-ctor.patch
# Make it possible to run the test suite in the FIPS mode
Patch19:	libgcrypt-1.5.3-fips-test.patch
# Make the FIPS RSA keygen be FIPS 186-4 compliant
Patch20:	libgcrypt-1.5.3-rsa-fips-keygen.patch
# Add configurable source of RNG seed and seed by default
# from /dev/urandom in the FIPS mode
Patch21:	libgcrypt-1.5.3-fips-cfgrandom.patch
# update the selftests for new FIPS requirements
Patch22:	libgcrypt-1.5.3-fips-reqs.patch
# Compatibility with glibc < 2.17
Patch160:	libgcrypt-1.5.3-secure_getenv.patch
BuildRequires:	gawk, libgpg-error-devel >= 1.4, pkgconfig
BuildRequires:	openssl
BuildRequires:	fipscheck
%if %{UsrMove}
%global library_dir %{_libdir}
Conflicts:	filesystem < 3
%else
%global library_dir /%{_lib}
BuildRequires:	symlinks
%endif
# this is needed only when patching the .texi doc
BuildRequires:	texinfo

%description
Libgcrypt is a general purpose crypto library based on the code used
in GNU Privacy Guard.

%package devel
Summary:	Development files for the libgcrypt package
License:	LGPLv2+ and GPLv2+
Group:		Development/Libraries
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	libgpg-error-devel
Requires(post):	/sbin/install-info
Requires(preun): /sbin/install-info

%description devel
Libgcrypt is a general purpose crypto library based on the code used
in GNU Privacy Guard. This package contains files needed to develop
applications using libgcrypt.

%prep
%setup -q
%patch2 -p1 -b .use-fipscheck
%patch5 -p1 -b .tests
%patch7 -p1 -b .cavs
%patch9 -p1 -b .leak
%patch11 -p1 -b .use-poll
%patch12 -p1 -b .aliasing
%patch13 -p1 -b .gccopt
%patch15 -p1 -b .pbkdf-speedup
%patch16 -p1 -b .whirlpool-bug
%patch17 -p1 -b .drbg
%patch18 -p1 -b .fips-ctor
%patch19 -p1 -b .fips-test
%patch20 -p1 -b .fips-keygen
%patch21 -p1 -b .cfgrandom
%patch22 -p1 -b .fips-reqs

# Prior to glibc 2.17, secure_getenv was __secure_getenv
%if 0%{?fedora} < 19 && 0%{?rhel} < 7
%patch160
%endif

%build
%configure \
		--enable-noexecstack \
		--enable-hmac-binary-check \
		--disable-static \
%ifarch sparc64
		--disable-asm \
%endif
		--disable-O-flag-munging

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Change /usr/lib64 back to /usr/lib.  This saves us from having to patch the
# script to "know" that -L/usr/lib64 should be suppressed, and also removes
# a file conflict between 32- and 64-bit versions of this package.
# Also replace my_host with none.
sed -i -e 's,^libdir="/usr/lib.*"$,libdir="/usr/lib",g' %{buildroot}%{_bindir}/libgcrypt-config
sed -i -e 's,^my_host=".*"$,my_host="none",g' %{buildroot}%{_bindir}/libgcrypt-config

# Remove files we don't want packaged
rm %{buildroot}%{_infodir}/dir
rm %{buildroot}%{_libdir}/*.la

# Relocate the shared libraries to /%%{_lib}
%if ! %{UsrMove}
mkdir -p %{buildroot}/%{_lib}
for shlib in %{buildroot}%{_libdir}/*.so*; do
	if [ -L ${shlib} ]; then
		shlib_target=$(basename $(readlink ${shlib}))
		rm ${shlib}
		[ $(basename ${shlib}) = libgcrypt.so ] && ln -s %{buildroot}/%{_lib}/${shlib_target} ${shlib}
	else
		mv ${shlib} %{buildroot}/%{_lib}/
	fi
done
symlinks -cs %{buildroot}%{_libdir}

# Add the soname symlink back in
/sbin/ldconfig -n %{buildroot}/%{_lib}/
%endif

# Create /etc/gcrypt (hardwired, not dependent on the configure invocation) so
# that _someone_ owns it.
mkdir -p -m 755 %{buildroot}/etc/gcrypt

%check
%{__fipshmac} src/.libs/libgcrypt.so.??
make check

# Add generation of HMAC checksums of the final stripped binaries 
%global __spec_install_post \
	%{?__debug_package:%{__debug_install_post}} \
	%{__arch_install_post} \
	%{__os_install_post} \
	%{__fipshmac} %{buildroot}%{library_dir}/*.so.?? \
%{nil}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/gcrypt.info.gz %{_infodir}/dir || :

%preun devel
if [ $1 = 0 ]; then
	/sbin/install-info --delete %{_infodir}/gcrypt.info.gz %{_infodir}/dir || :
fi

%files
%if 0%{?_licensedir:1}
%license COPYING.LIB
%else
%doc COPYING.LIB
%endif
%doc AUTHORS NEWS THANKS
%dir /etc/gcrypt
%{library_dir}/libgcrypt.so.11
%{library_dir}/libgcrypt.so.11.*
%{library_dir}/.libgcrypt.so.11.hmac

%files devel
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%{_bindir}/dumpsexp
%{_bindir}/hmac256
%{_bindir}/libgcrypt-config
%{_includedir}/gcrypt-module.h
%{_includedir}/gcrypt.h
%{_libdir}/libgcrypt.so
%{_datadir}/aclocal/libgcrypt.m4
%{_infodir}/gcrypt.info*

%changelog
* Sun Aug 21 2016 aul Howarth <paul@city-fan.org> - 1.5.6-1.0.cf
- Update to 1.5.6
  - Improved performance of RSA, DSA, and Elgamal by using a new exponentiation
    algorithm (CVE-2014-5270)
  - Fixed a subtle bug in mpi_set_bit that could set spurious bits
  - Fixed a bug in an internal division function
  - Mitigate chosen cipher text attacks on ECDH with Weierstrass curves
    [CVE-2015-7511)
  - Use ciphertext blinding for Elgamal decryption (CVE-2014-3591)
  - Fix critical security bug in the RNG (CVE-2016-6313); an attacker who
    obtains 580 bytes from the standard RNG can trivially predict the next 20
    bytes of output
- Use %%license where available
- Prefer %%global over %%define

* Sat Apr 11 2015 Paul Howarth <paul@city-fan.org> - 1.5.3-12.0.cf
- Use macros instead of inline functions in the public header
- Do not initialize secure memory during the self-test
- Update the self-tests for the new FIPS requirements
- Make the RSA keygen to be compliant to FIPS 186-4 in FIPS mode
- Add FIPS DRBG implementation
- Apply the fips-cfgrandom change also to the drbg seeding
- Run the FIPS POST tests in shared library constructor
- Make it possible to run the test suite in the FIPS mode

* Mon Apr 28 2014 Paul Howarth <paul@city-fan.org> - 1.5.3-4.0.cf
- Rebuild to sync with EL-7

* Wed Jan 22 2014 Paul Howarth <paul@city-fan.org> - 1.5.3-3.0.cf
- Fix a bug in the Whirlpool hash implementation
- Speed up the PBKDF2 computation

* Tue Oct 22 2013 Paul Howarth <paul@city-fan.org> - 1.5.3-2.0.cf
- Un-hobble - use upstream's ecc support

* Sat Jul 27 2013 Paul Howarth <paul@city-fan.org> - 1.5.3-1.0.cf
- Update to 1.5.3:
  - Mitigate the Yarom/Falkner flush+reload side-channel attack on RSA secret
    keys (see http://eprint.iacr.org/2013/448)

* Thu Jun 20 2013 Paul Howarth <paul@city-fan.org> - 1.5.2-3.0.cf
- Silence false error detected by valgrind (#968288)

* Thu Apr 25 2013 Paul Howarth <paul@city-fan.org> - 1.5.2-2.0.cf
- Silence strict aliasing warning in Rijndael

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> - 1.5.2-1.0.cf
- Update to 1.5.2:
  - Added support for IDEA
  - Made the Padlock code work again (regression since 1.5.0)
  - Fixed alignment problems for Serpent
  - Fixed two bugs in ECC computations

* Wed Mar 20 2013 Paul Howarth <paul@city-fan.org> - 1.5.1-1.0.cf
- Update to 1.5.1:
  - Allow empty passphrase with PBKDF2
  - Do not abort on an invalid algorithm number in gcry_cipher_get_algo_keylen
    and gcry_cipher_get_algo_blklen
  - Fixed some Valgrind warnings
  - Fixed a problem with select and high fd numbers
  - Improved the build system
  - Various minor bug fixes
  - New symbols GCRYCTL_SET_ENFORCED_FIPS_FLAG and GCRYPT_VERSION_NUMBER
- Drop upstreamed patches, update poll patch

* Thu Mar  7 2013 Paul Howarth <paul@city-fan.org> - 1.5.0-11.0.cf
- Use poll() instead of select() when gathering randomness (#913773)

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 1.5.0-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan  3 2013 Paul Howarth <paul@city-fan.org> - 1.5.0-9.0.cf
- Allow empty passphrase in PBKDF2 needed for cryptsetup (#891266)

* Mon Dec  3 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-8.0.cf
- Fix multilib conflict in libgcrypt-config
- Fix minor memory leaks and other bugs found by Coverity scan

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Apr  6 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-5.0.cf
- Add GCRYCTL_SET_ENFORCED_FIPS_FLAG command
- BR: texinfo since we're patching the .texi doc

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-4.0.cf
- From F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Retain upstream timestamps where possible
- Drop support for distributions prior to F-16:
  - Enable fipscheck unconditionally
  - Drop %%defattr, redundant since rpm 4.4
  - Drop buildroot definition and cleaning
  - devel sub-package never needs to require automake
  - Never need --disable-aesni-support

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Aug 15 2011 Paul Howarth <paul@city-fan.org> - 1.5.0-2.0.cf
- Rebuild for rpm bug #728707

* Thu Jul 21 2011 Paul Howarth <paul@city-fan.org> - 1.5.0-1.0.cf
- Update to 1.5.0
  - New function gcry_kdf_derive implementing OpenPGP S2K algorithms and PBKDF2
  - Support for WindowsCE
  - Support for ECDH
  - Support for OAEP and PSS methods as described by RFC-3447
  - Fixed PKCS v1.5 code to always return the leading zero
  - New format specifiers "%%M" and "%%u" for gcry_sexp_build
  - Support opaque MPIs with "%%m" and "%%M" in gcry_sexp_build
  - New functions gcry_pk_get_curve and gcry_pk_get_param to map ECC
    parameters to a curve name and to retrieve parameter values
  - gcry_mpi_cmp applied to opaque values has a defined semantic now
  - Uses the Intel AES-NI instructions if available
  - The use of the deprecated Alternative Public Key Interface (gcry_ac_*)
    will now print compile time warnings
  - The module register subsystem has been deprecated
  - CTR mode may now be used with data chunks of arbitrary length
- Disable AES-NI use for Fedora 4 i386 build, where it doesn't work
  (http://mail-index.netbsd.org/pkgsrc-users/2011/07/15/msg014687.html)
- Use a patch rather than scripted iconv to fix character encoding
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-4.0.cf
- Always xor seed from /dev/urandom over /etc/gcrypt/rngseed

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-3.0.cf
- Make the FIPS-186-3 DSA implementation CAVS testable
- Add configurable source of RNG seed /etc/gcrypt/rngseed
  in the FIPS mode (#700388)

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-2.0.cf
- Nobody else likes macros for commands

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-1.0.cf
- Update to 1.4.6
  - New variants of the TIGER algorithm
  - New cipher algorithm mode for AES-WRAP

* Mon Feb  7 2011 Paul Howarth <paul@city-fan.org> - 1.4.5-6.0.cf
- Fix a bug in the FIPs-186-3 dsa parameter generation code
- Use /dev/urandom for seeding in the FIPS mode
- Make the tests pass in the FIPS mode

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.4.5-5.0.cf
- Fix dist tag for RHEL-4
- Don't need automake dependency in devel package from F-14

* Tue Feb 23 2010 Paul Howarth <paul@city-fan.org> - 1.4.5-4.0.cf
- Update to 1.4.5
  - Fixed minor memory leak in DSA key generation
  - No more switching to FIPS mode if /proc/version is not readable
  - Fixed a sigill during Padlock detection on old CPUs
  - Fixed a hang on some W2000 machines
  - Boosted SHA-256/512 performance on ia32 boxes with gcc 4.3
- Fix FTBFS: ImplicitDSOLinking (#564973)
- Disable upstream's fiddling with compiler optimization flags
- Clarify license - some parts of devel package are GPLV2+
- Include credits, license text and NEWS as %%doc
- Change URL from directory.fsf.org to www.gnupg.org
- Tighten devel package's dependency on main package
- Dist tag for Rawhide no longer needs special-casing

* Thu Jun 18 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-6.0.cf
- Fix VIA padlock RNG inline assembly call (#505724)
- fipshmac moved from /bin to /usr/bin, except on EL-5, so cater for both

* Fri Mar  6 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-4.0.cf
- Rebuild for city-fan.org repo

* Thu Mar  5 2009 Tomas Mraz <tmraz@redhat.com> - 1.4.4-4
- With the integrity verification check the library needs to link to libdl
  (#488702)

* Wed Mar  4 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-3.0.cf
- Add hmac FIPS integrity verification check where openssl supports it

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-1.0.cf
- Import from Fedora
- Simplify library relocation to /%%{_lib} by using the symlinks program
- Kill rpaths to /usr/lib64
- Fix scriptlet dependencies
- Add URL tag
- This is a stable version, so remove bit about it being a development version
  from the package description

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jan 30 2009 Tomas Mraz <tmraz@redhat.com> - 1.4.4-1
- Update to 1.4.4
- Do not abort when the fips mode kernel flag is inaccessible
  due to permissions (#470219)
- Hobble the library to drop the ECC support

* Mon Oct 20 2008 Dennis Gilmore <dennis@ausil.us> - 1.4.3-2
- Disable asm on sparc64

* Thu Sep 18 2008 Nalin Dahyabhai <nalin@redhat.com> - 1.4.3-1
- Update to 1.4.3
- Own /etc/gcrypt

* Mon Sep 15 2008 Nalin Dahyabhai <nalin@redhat.com>
- Invoke make with %%{?_smp_mflags} to build faster on multi-processor
  systems (Steve Grubb)

* Mon Sep  8 2008 Nalin Dahyabhai <nalin@redhat.com> - 1.4.2-1
- Update to 1.4.2

* Tue Apr 29 2008 Nalin Dahyabhai <nalin@redhat.com> - 1.4.1-1
- Update to 1.4.1
- Bump libgpgerror-devel requirement to 1.4, matching the requirement enforced
  by the configure script

* Thu Apr  3 2008 Joe Orton <jorton@redhat.com> - 1.4.0-3
- Add patch from upstream to fix severe performance regression
  in entropy gathering

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.4.0-2
- Autorebuild for GCC 4.3

* Mon Dec 10 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.4.0-1
- Update to 1.4.0

* Tue Oct 16 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-6
- Use ldconfig to build the soname symlink for packaging along with the
  shared library (#334731)

* Wed Aug 22 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-5
- Add missing gawk buildrequirement
- Switch from explicitly specifying the /dev/random RNG to just verifying
  that the non-LGPL ones were disabled by the configure script

* Thu Aug 16 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-4
- Clarify license
- Force use of the linux /dev/random RNG, to avoid accidentally falling back
  to others, which would affect the license of the resulting library

* Mon Jul 30 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-3
- Disable static libraries (part of #249815)

* Fri Jul 27 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-2
- Move libgcrypt shared library to /%%{_lib} (#249815)

* Tue Feb  6 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-1
- Update to 1.2.4

* Mon Jan 22 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.3-2
- Make use of install-info more failsafe (Ville Skyttä, #223705)

* Fri Sep  1 2006 Nalin Dahyabhai <nalin@redhat.com> - 1.2.3-1
- Update to 1.2.3

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-3.1
- Rebuild

* Mon Jun 05 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-3
- Added missing buildreq pkgconfig

* Tue May 16 2006 Nalin Dahyabhai <nalin@redhat.com> - 1.2.2-2
- Remove file conflicts in libgcrypt-config by making the 64-bit version
  think the libraries are in /usr/lib (which is wrong, but which it also
  prunes from the suggest --libs output, so no harm done, hopefully)

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-1.2.1
- Bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-1.2
- Rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- Rebuilt

* Wed Oct  5 2005 Nalin Dahyabhai <nalin@redhat.com> - 1.2.2-1
- Update to 1.2.2

* Wed Mar 16 2005 Nalin Dahyabhai <nalin@redhat.com> - 1.2.1-1
- Update to 1.2.1

* Fri Jul 30 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- Another try to package the symlink

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Sun May  2 2004 Bill Nottingham <notting@redhat.com> - 1.2.0-1
- Update to official 1.2.0

* Fri Apr 16 2004 Bill Nottingham <notting@redhat.com> - 1.1.94-1
- Update to 1.1.94

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Sat Feb 21 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- Add symlinks to shared libs at compile time

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Thu Mar 20 2003 Jeff Johnson <jbj@redhat.com> - 1.1.12-1
- Upgrade to 1.1.12 (beta)

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- Automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- Automated rebuild

* Tue May 21 2002 Jeff Johnson <jbj@redhat.com>
- Update to 1.1.7
- Change license to LGPL
- Include splint annotations patch
- Install info pages

* Tue Apr  2 2002 Nalin Dahyabhai <nalin@redhat.com> - 1.1.6-1
- Update to 1.1.6

* Thu Jan 10 2002 Nalin Dahyabhai <nalin@redhat.com> - 1.1.5-1
- Fix the Source tag so that it's a real URL

* Thu Dec 20 2001 Nalin Dahyabhai <nalin@redhat.com>
- Initial package
